@@ -45,7 +45,7 @@
 #  SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #
 
-VERSION = (0, 3, 1, 'final', 0)
+VERSION = (0, 3, 2, 'final', 0)
 
 def get_version():
     version = '%d.%d.%d' % (VERSION[0], VERSION[1], VERSION[2])
@@ -69,12 +69,18 @@ implement the following:
 - migration to the Google-hosted reCaptcha API
 - extension of the available application settings
 - addition of a decorator that adds the remote IP to the submitted form
+- support for overriding the reCaptcha field validation to facilitate
+  form testing
 
+More information
+----------------
 More information about the installation, configuration and usage of this
 application can be found in the *HELP* file inside the distribution package
 or in the project's
 `wiki <http://www.codetrax.org/projects/django-recaptcha-works/wiki>`_.
 
+Bugs and new features
+---------------------
 In case you run into any problems while using this application it is highly
 recommended you file a bug report at the project's
 `issue tracker <http://www.codetrax.org/projects/django-recaptcha-works/issues>`_.
